<?php
/*
Plugin Name: 대가성 글 알림
Plugin URI: https://url.kr/p/wp-plugin/affiliate-notice
Description: 워드프레스 글 작성 시 대가성 글임을 알리는 문구를 자동으로 삽입하는 플러그인입니다.
Version: 1.5.0
Requires at least: 5.0
Requires PHP: 7.2
Author: 호텔천사
Author URI: https://webworks.co.kr
License: GPL v2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: affiliate-notice
Domain Path: /languages
*/

/*
- 파일명: affiliate-notice.php
- 위치: /affiliate-notice/affiliate-notice.php
- 기능: 플러그인 메인 파일, 초기화 및 기본 설정
- 작성일: 2025-03-22
- 수정일: 2025-03-23
*/

// 직접 접근 방지
if (!defined('ABSPATH')) {
    exit;
}

// ===================================
// 상수 정의
// ===================================
define('AFFNOTICE_VERSION', '1.0.0');
define('AFFNOTICE_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('AFFNOTICE_PLUGIN_URL', plugin_dir_url(__FILE__));

// ===================================
// 플러그인 활성화 및 비활성화 훅
// ===================================
register_activation_hook(__FILE__, 'affnotice_activate');
register_deactivation_hook(__FILE__, 'affnotice_deactivate');

/**
 * 플러그인 활성화 시 실행되는 함수
 *
 * @return void
 */
function affnotice_activate() {
    // 기본 옵션 설정
    $default_options = array(
        'notice_text' => '알림: 본 콘텐츠는 제휴 활동 상품에 따라 수수료를 지급받습니다.',
        'notice_style' => 'default',
        'notice_enabled' => 'yes',
        'always_enabled' => 'no'
    );
    
    // 기존 옵션이 없을 경우에만 기본 옵션 추가
    if (!get_option('affnotice_options')) {
        add_option('affnotice_options', $default_options);
    }

    // 캐시 비우기
    if (function_exists('wp_cache_flush')) {
        wp_cache_flush();
    }
}

/**
 * 플러그인 비활성화 시 실행되는 함수
 *
 * @return void
 */
function affnotice_deactivate() {
    // 플러그인 비활성화 시 필요한 작업
}

// ===================================
// 메타박스 추가 (글 작성 화면)
// ===================================
add_action('add_meta_boxes', 'affnotice_add_meta_boxes');
add_action('save_post', 'affnotice_save_meta_box_data');

/**
 * 글 편집 화면에 메타박스 추가
 *
 * @return void
 */
function affnotice_add_meta_boxes() {
    $post_types = array('post', 'page'); // 적용할 포스트 타입 설정
    
    foreach ($post_types as $post_type) {
        add_meta_box(
            'affnotice_meta_box',
            '대가성 글 알림',
            'affnotice_meta_box_callback',
            $post_type,
            'side',
            'high'
        );
    }
}

/**
 * 메타박스 내용 표시 콜백 함수
 *
 * @param WP_Post $post 현재 포스트 객체
 * @return void
 */
function affnotice_meta_box_callback($post) {
    // 논스 필드 추가
    wp_nonce_field('affnotice_meta_box', 'affnotice_meta_box_nonce');
    
    // 현재 저장된 값 가져오기
    $value = get_post_meta($post->ID, '_affnotice_enabled', true);
    
    // 옵션 가져오기
    $options = get_option('affnotice_options');
    $always_enabled = isset($options['always_enabled']) ? $options['always_enabled'] : 'no';
    
    // 글이 새로 작성되는 경우와 '항상 사용' 옵션이 활성화된 경우 체크박스를 체크 상태로 설정
    if (($always_enabled == 'yes' && empty($value)) || $value == 'yes') {
        $checked = 'checked';
    } else {
        $checked = '';
    }
    
    // 체크박스 출력
    ?>
    <div style="padding: 5px 0;">
        <input type="checkbox" id="affnotice_enabled" name="affnotice_enabled" <?php echo $checked; ?>>
        <label for="affnotice_enabled">
            이 글에 대가성 알림 표시하기
        </label>
    </div>
    <p class="description" style="margin-top: 8px; font-size: 12px; color: #666;">
        <?php if ($always_enabled == 'yes'): ?>
            대가성 알림이 모든 글에 자동으로 표시되도록 설정되어 있습니다.
        <?php else: ?>
            체크하면 글 상단에 대가성 알림이 표시됩니다.
        <?php endif; ?>
    </p>
    <?php
}

/**
 * 메타박스 데이터 저장
 *
 * @param int $post_id 현재 포스트 ID
 * @return void
 */
function affnotice_save_meta_box_data($post_id) {
    // 논스 확인
    if (!isset($_POST['affnotice_meta_box_nonce']) || !wp_verify_nonce($_POST['affnotice_meta_box_nonce'], 'affnotice_meta_box')) {
        return;
    }
    
    // 자동저장인 경우 처리하지 않음
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    
    // 권한 확인
    if (isset($_POST['post_type']) && 'page' === $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id)) {
            return;
        }
    } else {
        if (!current_user_can('edit_post', $post_id)) {
            return;
        }
    }
    
    // 데이터 저장
    if (isset($_POST['affnotice_enabled'])) {
        update_post_meta($post_id, '_affnotice_enabled', 'yes');
    } else {
        update_post_meta($post_id, '_affnotice_enabled', 'no');
    }
}

// ===================================
// 대가성 알림 표시 (프론트엔드)
// ===================================
// GeneratePress와의 호환성을 위해 우선순위를 15로 설정 (기본값은 10)
add_filter('the_content', 'affnotice_add_notice_to_content', 15);

/**
 * 콘텐츠에 대가성 알림 추가
 *
 * @param string $content 원본 콘텐츠
 * @return string 수정된 콘텐츠
 */
function affnotice_add_notice_to_content($content) {
    // 싱글 포스트나 페이지가 아니면 처리하지 않음
    if (!is_singular()) {
        return $content;
    }
    
    // RSS 피드에서는 표시하지 않음
    if (is_feed()) {
        return $content;
    }
    
    // 현재 포스트 ID
    $post_id = get_the_ID();
    
    // 옵션 가져오기
    $options = get_option('affnotice_options');
    $always_enabled = isset($options['always_enabled']) ? $options['always_enabled'] : 'no';
    
    // 대가성 알림 활성화 여부 확인
    $affnotice_enabled = get_post_meta($post_id, '_affnotice_enabled', true);
    
    // 항상 사용이 활성화되었거나 현재 글에 대가성 알림이 활성화된 경우
    if ($always_enabled == 'yes' || $affnotice_enabled == 'yes') {
        // 옵션 가져오기
        $notice_text = isset($options['notice_text']) ? $options['notice_text'] : '알림: 본 콘텐츠는 제휴 활동 상품에 따라 수수료를 지급받습니다.';
        $notice_style = isset($options['notice_style']) ? $options['notice_style'] : 'default';
        
        // 스타일에 따른 HTML 생성
        $notice_html = '<div class="affnotice-container affnotice-style-' . esc_attr($notice_style) . '">';
        $notice_html .= esc_html($notice_text);
        $notice_html .= '</div>';
        
        // 스타일 인라인 추가
        $notice_html .= '<style>
            .affnotice-container {
                margin-bottom: 20px !important;
                font-size: 0.95rem !important;
                line-height: 1.5 !important;
                clear: both !important;
                width: 100% !important;
            }
            
            /* 기본 스타일 */
            .affnotice-style-default {
                background-color: #f0f2ff !important;
                color: #3a3a3a !important;
                padding: 12px 15px !important;
                border-radius: 4px !important;
            }
            
            /* 테두리 스타일 */
            .affnotice-style-bordered {
                background-color: #ffffff !important;
                border: 1px solid #cccccc !important;
                color: #333333 !important;
                padding: 12px 15px !important;
                border-radius: 4px !important;
            }
            
            /* 강조 스타일 */
            .affnotice-style-highlighted {
                background-color: #fffdeb !important;
                border-left: 4px solid #ffcc00 !important;
                color: #333333 !important;
                padding: 10px 15px !important;
            }
            
            /* 모던 스타일 */
            .affnotice-style-modern {
                background-color: #e9f7fe !important;
                border-left: 4px solid #4dabf7 !important;
                color: #1864ab !important;
                padding: 10px 15px !important;
                box-shadow: 0 2px 4px rgba(0,0,0,0.05) !important;
            }
            
            /* 그라데이션 스타일 */
            .affnotice-style-gradient {
                background: linear-gradient(135deg, #f5f7ff 0%, #e3e9ff 100%) !important;
                color: #333333 !important;
                padding: 12px 15px !important;
                border-radius: 4px !important;
                box-shadow: 0 2px 5px rgba(0,0,0,0.05) !important;
            }
            
            /* 둥근 캡슐 스타일 */
            .affnotice-style-capsule {
                background-color: #f8f9fa !important;
                color: #495057 !important;
                padding: 10px 20px !important;
                border-radius: 50px !important;
                border: 1px solid #e9ecef !important;
                display: inline-block !important;
                margin-bottom: 15px !important;
            }
            
            /* 최소한의 스타일 */
            .affnotice-style-minimal {
                border-top: 1px solid #e9ecef !important;
                border-bottom: 1px solid #e9ecef !important;
                padding: 10px 0 !important;
                color: #6c757d !important;
                font-size: 0.9rem !important;
                margin-bottom: 20px !important;
            }
            
            /* 알림 박스 스타일 */
            .affnotice-style-alert {
                background-color: #fff3cd !important;
                color: #856404 !important;
                padding: 12px 15px !important;
                border-radius: 4px !important;
                border: 1px solid #ffeeba !important;
                display: flex !important;
                align-items: center !important;
            }
            .affnotice-style-alert:before {
                content: "\\26A0" !important;
                margin-right: 10px !important;
                font-size: 1.2em !important;
            }
            
            /* 다크 스타일 */
            .affnotice-style-dark {
                background-color: #343a40 !important;
                color: #ffffff !important;
                padding: 12px 15px !important;
                border-radius: 4px !important;
            }
            
            /* 뱃지 스타일 */
            .affnotice-style-badge {
                display: inline-block !important;
                background-color: #6c757d !important;
                color: #ffffff !important;
                padding: 5px 12px !important;
                border-radius: 4px !important;
                font-size: 0.85rem !important;
                font-weight: 600 !important;
                text-transform: uppercase !important;
                letter-spacing: 0.5px !important;
            }
        </style>';
        
        // 콘텐츠 상단에 알림 추가
        $content = $notice_html . $content;
    }
    
    return $content;
}

// ===================================
// 관리자 페이지 스타일 및 스크립트
// ===================================
add_action('admin_enqueue_scripts', 'affnotice_admin_scripts');

/**
 * 관리자 페이지에 스타일 및 스크립트 로드
 *
 * @param string $hook 현재 관리자 페이지 훅
 * @return void
 */
function affnotice_admin_scripts($hook) {
    if ('settings_page_affiliate_notice' != $hook) {
        return;
    }
    
    // Bootstrap 5 CSS
    wp_enqueue_style('bootstrap', 'https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css');
    
    // Bootstrap Icons
    wp_enqueue_style('bootstrap-icons', 'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.0/font/bootstrap-icons.css');
    
    // jQuery (워드프레스 기본 제공)
    wp_enqueue_script('jquery');
    
    // Bootstrap 5 JS
    wp_enqueue_script('bootstrap', 'https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js', array('jquery'), '5.3.0', true);
    
    // 관리자 페이지 인라인 스타일
    wp_add_inline_style('bootstrap', '
        .affnotice-dashboard {
            background-color: #f8f9fa;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.05);
            overflow: hidden;
            margin-top: 20px;
        }
        .affnotice-header {
            background-color: #fff;
            padding: 15px 20px;
            border-bottom: 1px solid #e9ecef;
        }
        .affnotice-header h2 {
            margin: 0;
            font-size: 18px;
            display: flex;
            align-items: center;
        }
        .affnotice-header h2 i {
            margin-right: 8px;
            color: #0d6efd;
        }
        .affnotice-content {
            padding: 20px;
            background-color: #fff;
        }
        .affnotice-nav {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #e9ecef;
            padding-bottom: 10px;
        }
        .affnotice-nav-item {
            padding: 10px 15px;
            margin-right: 5px;
            border-radius: 4px 4px 0 0;
            font-weight: 500;
            color: #495057;
            text-decoration: none;
            border-bottom: 3px solid transparent;
        }
        .affnotice-nav-item:hover {
            background-color: #f8f9fa;
            color: #0d6efd;
        }
        .affnotice-nav-item.active {
            color: #0d6efd;
            border-bottom-color: #0d6efd;
        }
        .affnotice-nav-item i {
            margin-right: 5px;
        }
        .affnotice-card {
            background-color: #fff;
            border-radius: 6px;
            box-shadow: 0 1px 5px rgba(0,0,0,0.03);
            margin-bottom: 20px;
            border: 1px solid #e9ecef;
        }
        .affnotice-card-header {
            padding: 15px 20px;
            border-bottom: 1px solid #e9ecef;
            display: flex;
            align-items: center;
            background-color: #f8f9fa;
        }
        .affnotice-card-header h3 {
            margin: 0;
            font-size: 16px;
            font-weight: 600;
        }
        .affnotice-card-header i {
            margin-right: 8px;
            color: #0d6efd;
        }
        .affnotice-card-body {
            padding: 20px;
        }
        .affnotice-row {
            display: flex;
            flex-wrap: wrap;
            margin: 0 -10px;
        }
        .affnotice-col {
            flex: 0 0 33.333333%;
            max-width: 33.333333%;
            padding: 0 10px;
        }
        .style-preview-box {
            border: 1px solid #e9ecef;
            border-radius: 6px;
            transition: all 0.3s ease;
            overflow: hidden;
            height: 100%;
            cursor: pointer;
        }
        .style-preview-box:hover {
            transform: translateY(-2px);
            box-shadow: 0 5px 15px rgba(0,0,0,0.08);
        }
        .style-preview-header {
            padding: 10px;
            border-bottom: 1px solid #e9ecef;
            display: flex;
            align-items: center;
        }
        .style-preview-radio {
            margin-right: 8px;
        }
        .style-preview-title {
            font-weight: 500;
            font-size: 14px;
            margin: 0;
        }
        .style-preview-content {
            padding: 15px;
        }
        .style-preview {
            width: 100%;
            font-size: 13px;
            line-height: 1.4;
        }
        .style-selected {
            border-color: #0d6efd;
            box-shadow: 0 0 0 1px #0d6efd;
        }
        .input-group-text { 
            border-right: none; 
            background-color: #fff; 
        }
        .form-control { 
            border-left: none; 
            padding-left: 0; 
        }
        .stats-card {
            border-radius: 6px;
            box-shadow: 0 2px 8px rgba(0,0,0,0.05);
            padding: 15px;
            margin-bottom: 20px;
            display: flex;
            align-items: center;
            justify-content: space-between;
        }
        .stats-card-primary {
            background-color: #cfe2ff;
            color: #084298;
        }
        .stats-card-success {
            background-color: #d1e7dd;
            color: #0f5132;
        }
        .stats-card-warning {
            background-color: #fff3cd;
            color: #664d03;
        }
        .stats-icon {
            font-size: 24px;
            width: 40px;
            height: 40px;
            display: flex;
            align-items: center;
            justify-content: center;
            border-radius: 50%;
            background-color: rgba(255,255,255,0.4);
        }
        .stats-text {
            flex-grow: 1;
            margin-left: 15px;
        }
        .stats-value {
            font-size: 20px;
            font-weight: 600;
            line-height: 1;
            margin-bottom: 5px;
        }
        .stats-label {
            font-size: 13px;
            opacity: 0.8;
        }
        
        /* 스타일 미리보기 */
        .style-default {
            background-color: #f0f2ff;
            color: #3a3a3a;
            padding: 12px 15px;
            border-radius: 4px;
        }
        .style-bordered {
            background-color: #ffffff;
            border: 1px solid #ccc;
            color: #333;
            padding: 12px 15px;
            border-radius: 4px;
        }
        .style-highlighted {
            background-color: #fffdeb;
            border-left: 4px solid #ffcc00;
            color: #333;
            padding: 10px 15px;
        }
        .style-modern {
            background-color: #e9f7fe;
            border-left: 4px solid #4dabf7;
            color: #1864ab;
            padding: 10px 15px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.05);
        }
        .style-gradient {
            background: linear-gradient(135deg, #f5f7ff 0%, #e3e9ff 100%);
            color: #333333;
            padding: 12px 15px;
            border-radius: 4px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.05);
        }
        .style-capsule {
            background-color: #f8f9fa;
            color: #495057;
            padding: 8px 20px;
            border-radius: 50px;
            border: 1px solid #e9ecef;
            display: inline-block;
        }
        .style-minimal {
            border-top: 1px solid #e9ecef;
            border-bottom: 1px solid #e9ecef;
            padding: 10px 0;
            color: #6c757d;
            font-size: 0.9rem;
        }
        .style-alert {
            background-color: #fff3cd;
            color: #856404;
            padding: 12px 15px;
            border-radius: 4px;
            border: 1px solid #ffeeba;
            display: flex;
            align-items: center;
        }
        .style-alert:before {
            content: "\\26A0";
            margin-right: 10px;
            font-size: 1.2em;
        }
        .style-dark {
            background-color: #343a40;
            color: #ffffff;
            padding: 12px 15px;
            border-radius: 4px;
        }
        .style-badge {
            display: inline-block;
            background-color: #6c757d;
            color: #ffffff;
            padding: 5px 12px;
            border-radius: 4px;
            font-size: 0.85rem;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.5px;
        }
        
        @media (max-width: 768px) {
            .affnotice-col {
                flex: 0 0 50%;
                max-width: 50%;
                margin-bottom: 20px;
            }
        }
        
        @media (max-width: 576px) {
            .affnotice-col {
                flex: 0 0 100%;
                max-width: 100%;
            }
        }
    ');
    
    // 관리자 페이지 인라인 스크립트
    wp_add_inline_script('bootstrap', '
        jQuery(document).ready(function($) {
            // 탭 전환
            $(".affnotice-nav-item").on("click", function(e) {
                e.preventDefault();
                var targetTab = $(this).data("tab");
                
                // 탭 활성화
                $(".affnotice-nav-item").removeClass("active");
                $(this).addClass("active");
                
                // 탭 내용 표시
                $(".affnotice-tab-content").hide();
                $("#" + targetTab).show();
            });
            
            // 스타일 선택
            $(".style-preview-box").on("click", function() {
                var radioButton = $(this).find("input[type=\'radio\']");
                radioButton.prop("checked", true);
                
                // 스타일 선택 표시
                $(".style-preview-box").removeClass("style-selected");
                $(this).addClass("style-selected");
            });
            
            // 스타일 라디오 버튼 체크 시 상자 선택
            $("input[name=\'affnotice_options[notice_style]\']").on("change", function() {
                $(".style-preview-box").removeClass("style-selected");
                $(this).closest(".style-preview-box").addClass("style-selected");
            });
            
            // 페이지 로드 시 선택된 스타일 강조
            var selectedStyle = $("input[name=\'affnotice_options[notice_style]\']:checked").val();
            $("input[value=\'" + selectedStyle + "\']").closest(".style-preview-box").addClass("style-selected");
            
            // 알림 문구 변경 시 미리보기 업데이트
            $("#notice_text").on("input", function() {
                var noticeText = $(this).val() || "알림: 본 콘텐츠는 제휴 활동 상품에 따라 수수료를 지급받습니다.";
                $(".style-preview").text(noticeText);
            });
            
            // 초기 탭 활성화
            var initialTab = window.location.hash ? window.location.hash.substring(1) : "settings";
            $(".affnotice-nav-item[data-tab=\'" + initialTab + "\']").click();
        });
    ', 'after');
}

// ===================================
// 관리자 메뉴 및 설정 페이지
// ===================================
add_action('admin_menu', 'affnotice_add_admin_menu');
add_action('admin_init', 'affnotice_register_settings');

/**
 * 관리자 메뉴에 플러그인 메뉴 추가
 *
 * @return void
 */
function affnotice_add_admin_menu() {
    add_options_page(
        '대가성 글 알림 설정',
        '대가성 글 알림',
        'manage_options',
        'affiliate_notice',
        'affnotice_options_page'
    );
}


/**
 * 항상 사용 필드 콜백
 *
 * @return void
 */
function affnotice_always_enabled_callback() {
    $options = get_option('affnotice_options');
    $value = isset($options['always_enabled']) ? $options['always_enabled'] : 'no';
    ?>
    <div class="form-check form-switch">
        <input class="form-check-input" type="checkbox" id="always_enabled" name="affnotice_options[always_enabled]" value="yes" <?php checked($value, 'yes'); ?>>
        <label class="form-check-label" for="always_enabled">모든 글에 대가성 알림 자동 표시</label>
    </div>
    <p class="form-text mt-2">이 옵션을 활성화하면 개별 글 작성 시 체크박스 선택 없이도 모든 글에 대가성 알림이 자동으로 표시됩니다.</p>
    <?php
}



/**
 * 설정 등록
 *
 * @return void
 */
function affnotice_register_settings() {
    register_setting(
        'affnotice_option_group',
        'affnotice_options',
        'affnotice_sanitize_options'
    );
    
    add_settings_section(
        'affnotice_general_section',
        '기본 설정',
        'affnotice_general_section_callback',
        'affiliate_notice'
    );
    
    add_settings_field(
        'notice_text',
        '알림 문구',
        'affnotice_notice_text_callback',
        'affiliate_notice',
        'affnotice_general_section'
    );
    
    // 항상 사용 옵션 필드 추가
    add_settings_field(
        'always_enabled',
        '항상 사용',
        'affnotice_always_enabled_callback',
        'affiliate_notice',
        'affnotice_general_section'
    );
    
    add_settings_section(
        'affnotice_style_section',
        '스타일 설정',
        'affnotice_style_section_callback',
        'affiliate_notice'
    );
    
    add_settings_field(
        'notice_style',
        '스타일 선택',
        'affnotice_notice_style_callback',
        'affiliate_notice',
        'affnotice_style_section'
    );
}



/**
 * 옵션 값 검증
 *
 * @param array $input 입력 값
 * @return array 검증된 값
 */
function affnotice_sanitize_options($input) {
    $output = array();
    
    // 알림 문구
    if (isset($input['notice_text'])) {
        $output['notice_text'] = sanitize_text_field($input['notice_text']);
    }
    
    // 스타일
    if (isset($input['notice_style'])) {
        $allowed_styles = array('default', 'bordered', 'highlighted', 'modern', 'gradient', 'capsule', 'minimal', 'alert', 'dark', 'badge');
        $output['notice_style'] = in_array($input['notice_style'], $allowed_styles) ? $input['notice_style'] : 'default';
    }
    
    // 항상 사용 여부
    $output['always_enabled'] = isset($input['always_enabled']) ? 'yes' : 'no';
    
    // 기존 옵션 유지
    $options = get_option('affnotice_options');
    if (isset($options['notice_enabled'])) {
        $output['notice_enabled'] = $options['notice_enabled'];
    }
    
    return $output;
}


/**
 * 설정 페이지 HTML 출력
 *
 * @return void
 */
function affnotice_options_page() {
    // 통계 데이터 수집
    $post_count = wp_count_posts();
    $published_posts = $post_count->publish;
    
    // 대가성 알림이 활성화된 글 수 계산
    global $wpdb;
    $affiliate_post_count = $wpdb->get_var(
        "SELECT COUNT(*) FROM $wpdb->postmeta 
         WHERE meta_key = '_affnotice_enabled' 
         AND meta_value = 'yes'"
    );
    
    // 비율 계산
    $affiliate_percentage = $published_posts > 0 ? round(($affiliate_post_count / $published_posts) * 100, 1) : 0;
    
    // 옵션 가져오기
    $options = get_option('affnotice_options');
    $notice_text = isset($options['notice_text']) ? $options['notice_text'] : '알림: 본 콘텐츠는 제휴 활동 상품에 따라 수수료를 지급받습니다.';
    $notice_style = isset($options['notice_style']) ? $options['notice_style'] : 'default';
    ?>
    <div class="wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        
        <div class="affnotice-dashboard">
            <div class="affnotice-header">
                <h2><i class="bi bi-megaphone-fill"></i> 대가성 글 알림 대시보드</h2>
            </div>
            
            <div class="affnotice-content">
                <!-- 통계 정보 -->
               <div class="affnotice-row mb-4">
                   <div class="col-md-4">
                       <div class="stats-card stats-card-primary">
                           <div class="stats-icon">
                               <i class="bi bi-file-earmark-text"></i>
                           </div>
                           <div class="stats-text">
                               <div class="stats-value"><?php echo $published_posts; ?></div>
                               <div class="stats-label">총 게시글 수</div>
                           </div>
                       </div>
                   </div>
                   <div class="col-md-4">
                       <div class="stats-card stats-card-success">
                           <div class="stats-icon">
                               <i class="bi bi-megaphone"></i>
                           </div>
                           <div class="stats-text">
                               <div class="stats-value"><?php echo $affiliate_post_count; ?></div>
                               <div class="stats-label">대가성 글 수</div>
                           </div>
                       </div>
                   </div>
                   <div class="col-md-4">
                       <div class="stats-card stats-card-warning">
                           <div class="stats-icon">
                               <i class="bi bi-percent"></i>
                           </div>
                           <div class="stats-text">
                               <div class="stats-value"><?php echo $affiliate_percentage; ?>%</div>
                               <div class="stats-label">대가성 글 비율</div>
                           </div>
                       </div>
                   </div>
               </div>
               
               <!-- 탭 메뉴 -->
               <div class="affnotice-nav">
                   <a href="#settings" class="affnotice-nav-item active" data-tab="settings">
                       <i class="bi bi-gear"></i> 설정
                   </a>
                   <a href="#styles" class="affnotice-nav-item" data-tab="styles">
                       <i class="bi bi-palette"></i> 스타일 선택
                   </a>
                   <a href="#help" class="affnotice-nav-item" data-tab="help">
                       <i class="bi bi-question-circle"></i> 도움말
                   </a>
               </div>
               
               <!-- 탭 컨텐츠 -->
               <div class="affnotice-tab-content" id="settings">
					<div class="affnotice-card">
						<div class="affnotice-card-header">
							<i class="bi bi-sliders"></i>
							<h3>기본 설정</h3>
						</div>
						<div class="affnotice-card-body">
							<form method="post" action="options.php">
								<?php settings_fields('affnotice_option_group'); ?>
								
								<div class="mb-4">
									<label for="notice_text" class="form-label fw-bold">알림 문구</label>
									<div class="input-group" style="max-width: 600px;">
										<span class="input-group-text bg-white border-end-0">
											<i class="bi bi-card-text text-primary"></i>
										</span>
										<input type="text" id="notice_text" name="affnotice_options[notice_text]" class="form-control border-start-0" value="<?php echo esc_attr($notice_text); ?>" placeholder="알림 문구를 입력하세요">
									</div>
									<p class="form-text mt-2">대가성 글임을 알리는 문구를 입력하세요. 미리보기에 실시간으로 반영됩니다.</p>
								</div>
								
								<!-- 항상 사용 옵션 추가 -->
								<div class="mb-4">
									<label class="form-label fw-bold">알림 표시 설정</label>
									<div class="d-flex align-items-center mb-2">
										<?php 
										$always_enabled = isset($options['always_enabled']) ? $options['always_enabled'] : 'no';
										?>
										<div class="custom-toggle-switch me-2">
											<input type="checkbox" id="always_enabled" name="affnotice_options[always_enabled]" value="yes" <?php checked($always_enabled, 'yes'); ?> class="custom-toggle-input">
											<label for="always_enabled" class="custom-toggle-label"></label>
										</div>
										<span id="toggle-status" class="ms-1" style="font-size: 0.9rem; font-weight: 500; color: <?php echo ($always_enabled == 'yes') ? '#0d6efd' : '#6c757d'; ?>">
											<?php echo ($always_enabled == 'yes') ? '사용' : '미사용'; ?>
										</span>
									</div>
									<p class="form-text">이 옵션을 활성화하면 개별 글 작성 시 체크박스 선택 없이도 모든 글에 대가성 알림이 자동으로 표시됩니다.</p>
								</div>

								<style>
								.custom-toggle-switch {
									position: relative;
									display: inline-block;
									width: 48px;
									height: 24px;
								}

								.custom-toggle-input {
									opacity: 0;
									width: 0;
									height: 0;
								}

								.custom-toggle-label {
									position: absolute;
									cursor: pointer;
									top: 0;
									left: 0;
									right: 0;
									bottom: 0;
									background-color: #ccc;
									transition: .4s;
									border-radius: 24px;
								}

								.custom-toggle-label:before {
									position: absolute;
									content: "";
									height: 18px;
									width: 18px;
									left: 3px;
									bottom: 3px;
									background-color: white;
									transition: .4s;
									border-radius: 50%;
								}

								.custom-toggle-input:checked + .custom-toggle-label {
									background-color: #2196F3;
								}

								.custom-toggle-input:checked + .custom-toggle-label:before {
									transform: translateX(24px);
								}
								</style>

								<script>
								jQuery(document).ready(function($) {
									// 토글 스위치 상태 변경 시 텍스트 업데이트
									$('#always_enabled').on('change', function() {
										if ($(this).is(':checked')) {
											$('#toggle-status').text('사용').css('color', '#0d6efd');
										} else {
											$('#toggle-status').text('미사용').css('color', '#6c757d');
										}
									});
								});
								</script>
								
								<!-- 현재 스타일 미리보기 -->
								<div class="mt-4">
									<label class="form-label fw-bold">현재 스타일 미리보기</label>
									<div class="style-preview style-<?php echo esc_attr($notice_style); ?>" style="max-width: 600px;">
										<?php echo esc_html($notice_text); ?>
									</div>
								</div>
								
								<div class="d-flex justify-content-end mt-4">
									<input type="hidden" name="affnotice_options[notice_style]" value="<?php echo esc_attr($notice_style); ?>">
									<?php submit_button('설정 저장', 'primary', 'submit', false); ?>
								</div>
							</form>
						</div>
					</div>
				</div>
               
               <div class="affnotice-tab-content" id="styles" style="display: none;">
                   <div class="affnotice-card">
                       <div class="affnotice-card-header">
                           <i class="bi bi-palette"></i>
                           <h3>스타일 선택</h3>
                       </div>
                       <div class="affnotice-card-body">
                           <p class="mb-4">원하는 스타일을 선택하세요. 변경 내용은 설정을 저장해야 적용됩니다.</p>
                           
                           <form method="post" action="options.php">
                               <?php settings_fields('affnotice_option_group'); ?>
                               
                               <div class="affnotice-row">
                                   <!-- 스타일 1: 기본 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_default" value="default" <?php checked($notice_style, 'default'); ?>>
                                               <label class="style-preview-title" for="style_default">기본 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-default">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 2: 테두리 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_bordered" value="bordered" <?php checked($notice_style, 'bordered'); ?>>
                                               <label class="style-preview-title" for="style_bordered">테두리 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-bordered">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 3: 강조 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_highlighted" value="highlighted" <?php checked($notice_style, 'highlighted'); ?>>
                                               <label class="style-preview-title" for="style_highlighted">강조 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-highlighted">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 4: 모던 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_modern" value="modern" <?php checked($notice_style, 'modern'); ?>>
                                               <label class="style-preview-title" for="style_modern">모던 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-modern">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 5: 그라데이션 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_gradient" value="gradient" <?php checked($notice_style, 'gradient'); ?>>
                                               <label class="style-preview-title" for="style_gradient">그라데이션 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-gradient">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 6: 둥근 캡슐 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_capsule" value="capsule" <?php checked($notice_style, 'capsule'); ?>>
                                               <label class="style-preview-title" for="style_capsule">둥근 캡슐 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-capsule">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 7: 최소한의 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_minimal" value="minimal" <?php checked($notice_style, 'minimal'); ?>>
                                               <label class="style-preview-title" for="style_minimal">최소한의 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-minimal">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 8: 알림 박스 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_alert" value="alert" <?php checked($notice_style, 'alert'); ?>>
                                               <label class="style-preview-title" for="style_alert">알림 박스 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-alert">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 9: 다크 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_dark" value="dark" <?php checked($notice_style, 'dark'); ?>>
                                               <label class="style-preview-title" for="style_dark">다크 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-dark">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <!-- 스타일 10: 뱃지 스타일 -->
                                   <div class="affnotice-col mb-4">
                                       <div class="style-preview-box">
                                           <div class="style-preview-header">
                                               <input type="radio" class="style-preview-radio" name="affnotice_options[notice_style]" id="style_badge" value="badge" <?php checked($notice_style, 'badge'); ?>>
                                               <label class="style-preview-title" for="style_badge">뱃지 스타일</label>
                                           </div>
                                           <div class="style-preview-content">
                                               <div class="style-preview style-badge">
                                                   <?php echo esc_html($notice_text); ?>
                                               </div>
                                           </div>
                                       </div>
                                   </div>
                               </div>
                               
                               <input type="hidden" name="affnotice_options[notice_text]" value="<?php echo esc_attr($notice_text); ?>">
                               
                               <div class="d-flex justify-content-end mt-3">
                                   <?php submit_button('스타일 저장', 'primary', 'submit', false); ?>
                               </div>
                           </form>
                       </div>
                   </div>
               </div>
               
               <div class="affnotice-tab-content" id="help" style="display: none;">
                   <div class="affnotice-card">
                       <div class="affnotice-card-header">
                           <i class="bi bi-question-circle"></i>
                           <h3>도움말</h3>
                       </div>
                       <div class="affnotice-card-body">
                           
						   <div class="mb-4">
								<h4 class="mb-3"><i class="bi bi-info-circle text-primary me-2"></i>플러그인 사용 방법</h4>
								<div class="ps-4">
									<p class="mb-2"><strong>1. 기본 설정하기</strong></p>
									<ul class="mb-3">
										<li>'설정' 탭에서 알림 문구를 설정합니다.</li>
										<li>'항상 사용' 옵션을 활성화하면 모든 글에 자동으로 대가성 알림이 표시됩니다.</li>
										<li>'스타일 선택' 탭에서 원하는 디자인을 선택합니다.</li>
										<li>모든 설정 변경 후 '설정 저장' 또는 '스타일 저장' 버튼을 클릭합니다.</li>
									</ul>
									
									<p class="mb-2"><strong>2. 글 작성 시 대가성 알림 설정</strong></p>
									<ul class="mb-3">
										<li>'항상 사용' 옵션이 비활성화된 경우, 워드프레스 글 작성/편집 화면의 우측에 있는 '대가성 글 알림 설정' 메타박스에서 체크박스를 선택합니다.</li>
										<li>'항상 사용' 옵션이 활성화된 경우, 별도의 선택 없이 모든 글에 대가성 알림이 표시됩니다.</li>
									</ul>
									
									<p class="mb-2"><strong>3. 결과 확인</strong></p>
									<ul>
										<li>글이 발행되면 설정된 스타일로 알림 문구가 글 상단에 자동으로 표시됩니다.</li>
										<li>대시보드에서 대가성 글의 통계를 확인할 수 있습니다.</li>
									</ul>
								</div>
							</div>
                           
                           <div class="mb-4">
                               <h4 class="mb-3"><i class="bi bi-lightbulb text-warning me-2"></i>자주 묻는 질문</h4>
                               
                               <div class="accordion" id="faqAccordion">
                                   <div class="accordion-item mb-2">
                                       <h2 class="accordion-header" id="faqOne">
                                           <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#collapseOne" aria-expanded="false" aria-controls="collapseOne">
                                               알림 문구를 여러 개 설정할 수 있나요?
                                           </button>
                                       </h2>
                                       <div id="collapseOne" class="accordion-collapse collapse" aria-labelledby="faqOne" data-bs-parent="#faqAccordion">
                                           <div class="accordion-body">
                                               현재 버전에서는 하나의 공통 문구만 설정 가능합니다. 향후 업데이트에서 글별 개별 문구 설정 기능을 추가할 계획입니다.
                                           </div>
                                       </div>
                                   </div>
                                   
                                   <div class="accordion-item mb-2">
                                       <h2 class="accordion-header" id="faqTwo">
                                           <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#collapseTwo" aria-expanded="false" aria-controls="collapseTwo">
                                               알림 위치를 글 하단으로 변경할 수 있나요?
                                           </button>
                                       </h2>
                                       <div id="collapseTwo" class="accordion-collapse collapse" aria-labelledby="faqTwo" data-bs-parent="#faqAccordion">
                                           <div class="accordion-body">
                                               현재 버전에서는 글 상단에만 표시됩니다. 향후 업데이트에서 위치 선택 옵션을 추가할 계획입니다.
                                           </div>
                                       </div>
                                   </div>						   
                                   
                                   <div class="accordion-item">
                                       <h2 class="accordion-header" id="faqThree">
                                           <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#collapseThree" aria-expanded="false" aria-controls="collapseThree">
                                               스타일을 직접 커스터마이징할 수 있나요?
                                           </button>
                                       </h2>
                                       <div id="collapseThree" class="accordion-collapse collapse" aria-labelledby="faqThree" data-bs-parent="#faqAccordion">
                                           <div class="accordion-body">
                                               현재는 10가지 스타일 중에서 선택만 가능합니다. 향후 업데이트에서 색상, 폰트 등을 직접 설정할 수 있는 커스텀 스타일 기능을 추가할 예정입니다.
                                           </div>
                                       </div>
                                   </div>
								   
								   <div class="accordion-item mb-2">
										<h2 class="accordion-header" id="faqFour">
											<button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#collapseFour" aria-expanded="false" aria-controls="collapseFour">
												모든 글에 자동으로 대가성 알림을 표시할 수 있나요?
											</button>
										</h2>
										<div id="collapseFour" class="accordion-collapse collapse" aria-labelledby="faqFour" data-bs-parent="#faqAccordion">
											<div class="accordion-body">
												네, '설정' 탭에서 '항상 사용' 옵션을 활성화하면 각 글마다 체크박스를 선택하지 않아도 모든 글에 자동으로 대가성 알림이 표시됩니다.
											</div>
										</div>
								   </div>
								   
								   
                               </div>
                           </div>
                           
                           <div class="alert alert-info d-flex align-items-center">
                               <i class="bi bi-envelope-fill me-3 fs-4"></i>
                               <div>
                                   <p class="mb-0">더 궁금한 점이 있으시면 언제든지 문의해 주세요.</p>
                               </div>
                           </div>
                       </div>
                   </div>
               </div>
           </div>
       </div>
   </div>
   <?php
}